# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/parse_resume_location.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/parse_resume_location.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*zetasql/public/parse_resume_location.proto\x12\x07zetasql\"h\n\x18ParseResumeLocationProto\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\r\n\x05input\x18\x01 \x01(\t\x12\x15\n\rbyte_position\x18\x02 \x01(\x05\x12\x14\n\x0c\x61llow_resume\x18\x03 \x01(\x08\x42#\n\x12\x63om.google.zetasqlB\rZetaSQLParser')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.parse_resume_location_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\rZetaSQLParser'
  _globals['_PARSERESUMELOCATIONPROTO']._serialized_start=55
  _globals['_PARSERESUMELOCATIONPROTO']._serialized_end=159
# @@protoc_insertion_point(module_scope)
